@@ -20,24 +20,36 @@
 
 #include "types.h"
 
+#include <QFileInfo>
+
 namespace PlasmaVault {
 
-static QString validateDevice(QString device)
+static QString normalizePath(const QString& path)
 {
-    if (device.endsWith('/')) {
-        device.chop(1);
+    QFileInfo fileInfo(path);
+
+    auto result = fileInfo.canonicalFilePath();
+
+    if (result.isEmpty()) {
+        result = path;
     }
-    return device;
+
+    if (result.endsWith('/')) {
+        result.chop(1);
+    }
+
+    return result;
 }
 
 Device::Device(const QString &device)
-    : m_device(validateDevice(device))
+    : m_device(device)
 {
 }
 
 Device::operator QString() const
 {
-    return m_device;
+    // Done here because canonicalFilePath relies on file existence
+    return normalizePath(m_device);
 }
 
 MountPoint::MountPoint(const QString &mountPoint)
@@ -47,7 +59,8 @@ MountPoint::MountPoint(const QString &mountPoint)
 
 MountPoint::operator QString() const
 {
-    return m_mountPoint;
+    // Done here because canonicalFilePath relies on file existence
+    return normalizePath(m_mountPoint);
 }
 
 } // namespace PlasmaVault
